@@ -1,3 +1,5 @@
+import re
+
 from dez.http.server import HTTPDaemon, HTTPResponse, HTTPVariableResponse, WSGIResponse
 from dez.http.static import StaticHandler
 from dez.http.wsgithreadpool import WSGIThreadPool
@@ -90,6 +92,22 @@ class HTTPApplication(object):
         if not self.wsgi_pool:
             self.wsgi_pool = WSGIThreadPool()
             
+        script_name = prefix
+        script_name_match = re.match(r"/(\S+?)\/?$", script_name)
+        if script_name_match:
+            script_name = "/" + script_name_match.group(1)
+        
+        if script_name != "/":
+            try:
+                from paste.deploy.config import PrefixMiddleware
+                app = PrefixMiddleware(app, prefix=script_name)
+            except ImportError:
+                message = "could not import PrefixMiddleware from\n"
+                message += "paste.deploy.config.\n"
+                message += "You must install PasteDeploy before you can"
+                message += " load a Pylons application.\n"
+                raise ImportError(message)
+        
         def wsgi_cb(req):
             r = WSGIResponse(req, app, self.host, self.port)
             self.wsgi_pool.dispatch(r)
