@@ -75,7 +75,7 @@ class HTTPConnection(object):
         self.revent = event.read(self.sock, self.read_ready)
         self.request = HTTPRequest(self)
         self.write_buffer = Buffer(mode='consume')
-        self.buffer = Buffer(mode="consume")
+        self.buffer = Buffer()
         self.state = "read"
         
     def close(self, reason=""):
