@@ -2,7 +2,7 @@ from dez.network.server import SocketDaemon
 from dez.op.server.validator import OPValidator
 from dez.op.server.connection import OPConnection
 
-print 'new dez server'
+print 'new dez op server'
 
 class OPServer(object):
     def __init__(self, addr, port):
