@@ -1,12 +1,12 @@
 from dez.network import SocketClient, SocketDaemon, Connection
 import sys
 
-def main2(*args):
+def main2(*args,**kwargs):
     client = SocketClient(cb=LocalEchoHTTPClient)
-    client.connect("www.google.com",80)
+    client.connect(kwargs['domain'],kwargs['port'])
 
-def main(port):
-    server = SocketDaemon("localhost", port, cb=EchoConnection)
+def main(**kwargs):
+    server = SocketDaemon(kwargs['domain'], kwargs['port'], cb=EchoConnection)
     server.start()
 
 class LocalEchoHTTPClient(object):
